==> jc-1.4.0.tar.gz: gnu/java/beans/editors/NativeIntEditor.h <==
// public class gnu.java.beans.editors.NativeIntEditor

// class file dependencies
// @dep_class da07794e4e396a01 gnu_java_beans_editors_NativeIntEditor
// @dep_class 5a63ffefcb362768 java_beans_PropertyEditorSupport
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_beans_PropertyEditorSupport

#include "java/beans/PropertyEditorSupport.h"

#ifndef _JC_gnu_java_beans_editors_NativeIntEditor_H_
#define _JC_gnu_java_beans_editors_NativeIntEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_editors_NativeIntEditor$sub_refs	_jc_gnu_java_beans_editors_NativeIntEditor$sub_refs;
typedef struct _jc_gnu_java_beans_editors_NativeIntEditor$sub_nonrefs	_jc_gnu_java_beans_editors_NativeIntEditor$sub_nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeIntEditor$refs	_jc_gnu_java_beans_editors_NativeIntEditor$refs;
typedef struct _jc_gnu_java_beans_editors_NativeIntEditor$nonrefs	_jc_gnu_java_beans_editors_NativeIntEditor$nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeIntEditor$object	_jc_gnu_java_beans_editors_NativeIntEditor$object;

typedef const struct _jc_gnu_java_beans_editors_NativeIntEditor$vmethods	_jc_gnu_java_beans_editors_NativeIntEditor$vmethods;
typedef const struct _jc_gnu_java_beans_editors_NativeIntEditor$vtable	_jc_gnu_java_beans_editors_NativeIntEditor$vtable;
typedef const struct _jc_gnu_java_beans_editors_NativeIntEditor$vtype	_jc_gnu_java_beans_editors_NativeIntEditor$vtype;

// Constructors
extern void _jc_gnu_java_beans_editors_NativeIntEditor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_editors_NativeIntEditor$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_editors_NativeIntEditor$method$getAsText$e78133031f0dd45a(_jc_env *, struct _jc_gnu_java_beans_editors_NativeIntEditor$object *);
extern void _jc_gnu_java_beans_editors_NativeIntEditor$method$setAsText$3108622962800f9f(_jc_env *, struct _jc_gnu_java_beans_editors_NativeIntEditor$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_editors_NativeIntEditor$method_info$getAsText$e78133031f0dd45a;
extern _jc_method _jc_gnu_java_beans_editors_NativeIntEditor$method_info$setAsText$3108622962800f9f;

// Virtual methods structure
struct _jc_gnu_java_beans_editors_NativeIntEditor$vmethods {
	struct _jc_java_lang_String$object	*(*getAsText$e78133031f0dd45a)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeIntEditor$object *);
	void	(*setAsText$3108622962800f9f)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeIntEditor$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_beans_editors_NativeIntEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_PropertyEditorSupport$vmethods	java_beans_PropertyEditorSupport;
	_jc_gnu_java_beans_editors_NativeIntEditor$vmethods	gnu_java_beans_editors_NativeIntEditor;
};

// Vtype
struct _jc_gnu_java_beans_editors_NativeIntEditor$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_editors_NativeIntEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeIntEditor$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeIntEditor$refs {
    _jc_gnu_java_beans_editors_NativeIntEditor$sub_refs	gnu_java_beans_editors_NativeIntEditor;
    _jc_java_beans_PropertyEditorSupport$sub_refs	java_beans_PropertyEditorSupport;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeIntEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeIntEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_PropertyEditorSupport$sub_nonrefs	java_beans_PropertyEditorSupport;
    _jc_gnu_java_beans_editors_NativeIntEditor$sub_nonrefs	gnu_java_beans_editors_NativeIntEditor;
};

// Object instance structure
struct _jc_gnu_java_beans_editors_NativeIntEditor$object {
	_jc_gnu_java_beans_editors_NativeIntEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_editors_NativeIntEditor$vtype	*vtype;
	_jc_gnu_java_beans_editors_NativeIntEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_editors_NativeIntEditor$vtype _jc_gnu_java_beans_editors_NativeIntEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_editors_NativeIntEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_editors_NativeIntEditor$class_object;

#endif	/* _JC_gnu_java_beans_editors_NativeIntEditor_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/editors/NativeIntEditor.h <==
// public class gnu.java.beans.editors.NativeIntEditor

// class file dependencies
// @dep_class da07794e4e396a01 gnu_java_beans_editors_NativeIntEditor
// @dep_class 5a63ffefcb362768 java_beans_PropertyEditorSupport
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_beans_PropertyEditorSupport

#include "java/beans/PropertyEditorSupport.h"

#ifndef _JC_gnu_java_beans_editors_NativeIntEditor_H_
#define _JC_gnu_java_beans_editors_NativeIntEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_editors_NativeIntEditor$sub_refs	_jc_gnu_java_beans_editors_NativeIntEditor$sub_refs;
typedef struct _jc_gnu_java_beans_editors_NativeIntEditor$sub_nonrefs	_jc_gnu_java_beans_editors_NativeIntEditor$sub_nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeIntEditor$refs	_jc_gnu_java_beans_editors_NativeIntEditor$refs;
typedef struct _jc_gnu_java_beans_editors_NativeIntEditor$nonrefs	_jc_gnu_java_beans_editors_NativeIntEditor$nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeIntEditor$object	_jc_gnu_java_beans_editors_NativeIntEditor$object;

typedef const struct _jc_gnu_java_beans_editors_NativeIntEditor$vmethods	_jc_gnu_java_beans_editors_NativeIntEditor$vmethods;
typedef const struct _jc_gnu_java_beans_editors_NativeIntEditor$vtable	_jc_gnu_java_beans_editors_NativeIntEditor$vtable;
typedef const struct _jc_gnu_java_beans_editors_NativeIntEditor$vtype	_jc_gnu_java_beans_editors_NativeIntEditor$vtype;

// Constructors
extern void _jc_gnu_java_beans_editors_NativeIntEditor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_editors_NativeIntEditor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_editors_NativeIntEditor$method$getAsText$e78133031f0dd45a(_jc_env *, struct _jc_gnu_java_beans_editors_NativeIntEditor$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_editors_NativeIntEditor$method$setAsText$3108622962800f9f(_jc_env *, struct _jc_gnu_java_beans_editors_NativeIntEditor$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_editors_NativeIntEditor$method_info$getAsText$e78133031f0dd45a;
extern _jc_method _jc_gnu_java_beans_editors_NativeIntEditor$method_info$setAsText$3108622962800f9f;

// Virtual methods structure
struct _jc_gnu_java_beans_editors_NativeIntEditor$vmethods {
	struct _jc_java_lang_String$object	*(*getAsText$e78133031f0dd45a)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeIntEditor$object *) _JC_JCNI_ATTR;
	void	(*setAsText$3108622962800f9f)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeIntEditor$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_editors_NativeIntEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_PropertyEditorSupport$vmethods	java_beans_PropertyEditorSupport;
	_jc_gnu_java_beans_editors_NativeIntEditor$vmethods	gnu_java_beans_editors_NativeIntEditor;
};

// Vtype
struct _jc_gnu_java_beans_editors_NativeIntEditor$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_editors_NativeIntEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeIntEditor$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeIntEditor$refs {
    _jc_gnu_java_beans_editors_NativeIntEditor$sub_refs	gnu_java_beans_editors_NativeIntEditor;
    _jc_java_beans_PropertyEditorSupport$sub_refs	java_beans_PropertyEditorSupport;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeIntEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeIntEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_PropertyEditorSupport$sub_nonrefs	java_beans_PropertyEditorSupport;
    _jc_gnu_java_beans_editors_NativeIntEditor$sub_nonrefs	gnu_java_beans_editors_NativeIntEditor;
};

// Object instance structure
struct _jc_gnu_java_beans_editors_NativeIntEditor$object {
	_jc_gnu_java_beans_editors_NativeIntEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_editors_NativeIntEditor$vtype	*vtype;
	_jc_gnu_java_beans_editors_NativeIntEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_editors_NativeIntEditor$vtype _jc_gnu_java_beans_editors_NativeIntEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_editors_NativeIntEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_editors_NativeIntEditor$class_object;

#endif	/* _JC_gnu_java_beans_editors_NativeIntEditor_H_ */
